| Home | Libraries | People | FAQ | More

## Type Traits by Category

Type Traits that Describe the Properties of a Type
  Categorizing a Type
  General Type Properties
  Relationships Between Two Types
  Operator Type Traits
Type Traits that Transform One Type to Another
Synthesizing Types with Specific Alignments
Decomposing Function Types

| Copyright © 2000, 2011 Adobe Systems Inc, David Abrahams, Frederic Bron, Steve Cleary, Beman Dawes, Aleksey Gurtovoy, Howard Hinnant, Jesse Jones, Mat Marcus, Itay Maman, John Maddock, Alexander Nasonov, Thorsten Ottosen, Roman Perepelitsa, Robert Ramey, Jeremy Siek, Robert Stewart and Steven Watanabe Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)